pub enum ConfigError {
MissingServices,
MissingEndpoint,
EndpointParseError(String),
TcpIncomingError(String),
UriParseError(String),
HeaderParseError(String),
RateLimitParseError(String),
TLSSettingError(String),
AuthConfigError(String),
ResolutionError,
Unknown,
}Expand description
Errors for Config. This is a custom error type for handling configuration-related errors. It is used to provide more context to the error messages.
Variants
MissingServices
MissingEndpoint
EndpointParseError(String)
TcpIncomingError(String)
UriParseError(String)
HeaderParseError(String)
RateLimitParseError(String)
TLSSettingError(String)
AuthConfigError(String)
ResolutionError
Unknown