TlsServerConfig

Struct TlsServerConfig 

pub struct TlsServerConfig {
    pub config: Config,
    pub insecure: bool,
    pub client_ca_file: Option<String>,
    pub client_ca_pem: Option<String>,
    pub reload_client_ca_file: bool,
}

Fields

config: Config

The Config struct

insecure: bool

insecure do not setup a TLS server

client_ca_file: Option<String>

Path to the TLS cert to use by the server to verify a client certificate. (optional)

client_ca_pem: Option<String>

PEM encoded CA cert to use by the server to verify a client certificate. (optional)

reload_client_ca_file: bool

Reload the ClientCAs file when it is modified TODO(msardara): not implemented yet

Implementations

Source

impl TlsServerConfig

pub fn new() -> Self

Create a new TlsServerConfig

pub fn with_insecure(self, insecure: bool) -> Self

Set insecure (disable TLS)

pub fn with_client_ca_file(self, client_ca_file: &str) -> Self

Set CA file for client auth

pub fn with_client_ca_pem(self, client_ca_pem: &str) -> Self

Set CA pem for client auth

pub fn with_reload_client_ca_file(self, reload_client_ca_file: bool) -> Self

Set reload_client_ca_file

pub fn with_ca_file(self, ca_file: &str) -> Self

Set CA file

pub fn with_ca_pem(self, ca_pem: &str) -> Self

Set CA pem

pub fn with_include_system_ca_certs_pool( self, include_system_ca_certs_pool: bool, ) -> Self

Set include system CA certs pool

pub fn with_cert_file(self, cert_file: &str) -> Self

Set cert file

pub fn with_cert_pem(self, cert_pem: &str) -> Self

Set cert pem

pub fn with_key_file(self, key_file: &str) -> Self

Set key file

pub fn with_key_pem(self, key_pem: &str) -> Self

Set key pem

pub fn with_tls_version(self, tls_version: &str) -> Self

Set TLS version

pub fn with_reload_interval(self, reload_interval: Option<Duration>) -> Self

Set reload interval

pub fn load_rustls_server_config( &self, ) -> Result<Option<RustlsServerConfig>, ConfigError>