pub struct ClientConfig {
pub endpoint: String,
pub origin: Option<String>,
pub compression: Option<CompressionType>,
pub rate_limit: Option<String>,
pub tls_setting: TlsClientConfig,
pub keepalive: Option<KeepaliveConfig>,
pub connect_timeout: Duration,
pub request_timeout: Duration,
pub buffer_size: Option<usize>,
pub headers: HashMap<String, String>,
pub auth: AuthenticationConfig,
}Expand description
Struct for the client configuration. This struct contains the endpoint, origin, compression type, rate limit, TLS settings, keepalive settings, timeout settings, buffer size settings, headers, and auth settings. The client configuration can be converted to a tonic channel.
Fields
endpoint: StringThe target the client will connect to.
origin: Option<String>Origin for the client.
compression: Option<CompressionType>Compression type - TODO(msardara): not implemented yet.
rate_limit: Option<String>Rate Limits
tls_setting: TlsClientConfigTLS client configuration.
keepalive: Option<KeepaliveConfig>Keepalive parameters.
connect_timeout: DurationTimeout for the connection.
request_timeout: DurationTimeout per request.
buffer_size: Option<usize>ReadBufferSize.
headers: HashMap<String, String>The headers associated with gRPC requests.
auth: AuthenticationConfigAuth configuration for outgoing RPCs.
Implementations
Sourceimpl ClientConfig
impl ClientConfig
Sourcepub fn with_endpoint(endpoint: &str) -> Self
pub fn with_endpoint(endpoint: &str) -> Self
Creates a new client configuration with the given endpoint. This function will return a ClientConfig with the endpoint set and all other fields set to default.
pub fn with_origin(self, origin: &str) -> Self
pub fn with_compression(self, compression: CompressionType) -> Self
pub fn with_rate_limit(self, rate_limit: &str) -> Self
pub fn with_tls_setting(self, tls_setting: TLSSetting) -> Self
pub fn with_keepalive(self, keepalive: KeepaliveConfig) -> Self
pub fn with_connect_timeout(self, connect_timeout: Duration) -> Self
pub fn with_request_timeout(self, request_timeout: Duration) -> Self
pub fn with_buffer_size(self, buffer_size: usize) -> Self
pub fn with_headers(self, headers: HashMap<String, String>) -> Self
pub fn with_auth(self, auth: AuthenticationConfig) -> Self
Sourcepub fn to_channel(
&self,
) -> Result<impl GrpcService<Body, Error: Into<StdError> + Send, ResponseBody: Body<Data = Bytes, Error: Into<StdError> + Send> + Send + 'static, Future: Send> + Send + use<>, ConfigError>
pub fn to_channel( &self, ) -> Result<impl GrpcService<Body, Error: Into<StdError> + Send, ResponseBody: Body<Data = Bytes, Error: Into<StdError> + Send> + Send + 'static, Future: Send> + Send + use<>, ConfigError>
Converts the client configuration to a tonic channel. This function will return a Result with the channel if the configuration is valid. If the configuration is invalid, it will return a ConfigError. The function will set the headers, tls settings, keepalive settings, rate limit settings timeout settings, buffer size settings, and origin settings.