pub struct ServerConfig {
pub endpoint: String,
pub tls_setting: TlsServerConfig,
pub http2_only: bool,
pub max_frame_size: Option<u32>,
pub max_concurrent_streams: Option<u32>,
pub max_header_list_size: Option<u32>,
pub read_buffer_size: Option<usize>,
pub write_buffer_size: Option<usize>,
pub keepalive: KeepaliveServerParameters,
pub auth: AuthenticationConfig,
}Fields
endpoint: StringEndpoint is the address to listen on.
tls_setting: TlsServerConfigConfigures the protocol to use TLS.
http2_only: boolUse HTTP 2 only.
max_frame_size: Option<u32>Maximum size (in MiB) of messages accepted by the server.
max_concurrent_streams: Option<u32>MaxConcurrentStreams sets the limit on the number of concurrent streams to each ServerTransport.
max_header_list_size: Option<u32>Max header list size
read_buffer_size: Option<usize>ReadBufferSize for gRPC server.
write_buffer_size: Option<usize>WriteBufferSize for gRPC server.
keepalive: KeepaliveServerParametersKeepalive anchor for all the settings related to keepalive.
auth: AuthenticationConfigAuth for this receiver.
Implementations
Sourceimpl ServerConfig
Convert ServerConfig to IncomingServerConfig
This function takes a ServerConfig and a service and returns a ServerFuture.
The ServerFuture is a boxed future that returns a Result<(), tonic::transport::Error>.
The ServerFuture is created by creating a new TcpIncoming and then creating a new Server.
impl ServerConfig
Convert ServerConfig to IncomingServerConfig This function takes a ServerConfig and a service and returns a ServerFuture. The ServerFuture is a boxed future that returns a Result<(), tonic::transport::Error>. The ServerFuture is created by creating a new TcpIncoming and then creating a new Server.
pub fn with_endpoint(endpoint: &str) -> Self
pub fn with_tls_settings(self, tls_setting: TLSSetting) -> Self
pub fn with_http2_only(self, http2_only: bool) -> Self
pub fn with_max_frame_size(self, max_frame_size: Option<u32>) -> Self
pub fn with_max_concurrent_streams( self, max_concurrent_streams: Option<u32>, ) -> Self
pub fn with_max_header_list_size( self, max_header_list_size: Option<u32>, ) -> Self
pub fn with_read_buffer_size(self, read_buffer_size: Option<usize>) -> Self
pub fn with_write_buffer_size(self, write_buffer_size: Option<usize>) -> Self
pub fn with_keepalive(self, keepalive: KeepaliveServerParameters) -> Self
pub fn with_auth(self, auth: AuthenticationConfig) -> Self
pub fn to_server_future<S>( &self, svc: &[S], ) -> Result<Pin<Box<dyn Future<Output = Result<(), Error>> + Send>>, ConfigError>